<?php

function get_file_icon($file){
    $ext=strtolower(pathinfo($file, PATHINFO_EXTENSION));
    $icon="file-base.svg";
    switch($ext){
        case "jpg":
        case "webp":
        case "png":
        case "gif":
            $icon=getVignette(getcompletefilepath($file,true),300,300,false);
            break;
        case "svg":
            $icon=getcompletefilepath($file);
            break;
        case "mp3":
        case "aac":
            $icon="app/images/file-music.svg";
            break;
        case "mp4":
        case "avi":
            $icon="app/images/file-movie.svg";
            break;
        case "zip":
            $icon="app/images/file-zip.svg";
            break;
        case "pdf":
            $icon="app/images/file-pdf.svg";
            break;

    }
    return $icon;
}

/*
cette fonction reçoit un nom de fichier provenant des imports 
et renvoie un nom de fichier PLEIN à partir de la racine, car il peut s'agir de l'image d'origine ou de d'une vignette

*/
function getVignette($src,$destwidth=VIGNETTE_W,$destheight=VIGNETTE_H,$crop=VIGNETTE_C){
    // on travaille avec les adresses serveur et les adresses publiques !
    $image_completepath=getcompletefilepath(basename($src));
    $image_publicpath=getcompletefilepath(basename($src),true);
    $image_default="app/images/defaut.jpg";
    $image_default_oversize="app/images/defaut-oversize.jpg";

    if($src=="" || !file_exists($image_completepath) ){ return $image_default; }
    $ext_image=array('jpg','png','gif','webp');

    $infos=pathinfo($image_completepath);
    $ext=strtolower($infos['extension']);
    $nom=$infos['filename'];

    if($ext=="svg"){ return $image_publicpath; }
    if(!in_array($ext,$ext_image)){ return $image_default; }

    $suffixe="_".$destwidth."x".$destheight.($crop ? "_crop" : "_nocrop");

    $vignette_completepath=CACHE_VIGNETTES.$nom.$suffixe.".".$ext;
    $vignette_publicpath=CACHE_VIGNETTES_URL.$nom.$suffixe.".".$ext;

    // voir si la vignette existe déjà, si oui la renvoyer directement
    if(file_exists($vignette_completepath)){
        return $vignette_publicpath."?".filectime($vignette_completepath);
    } 
    // si le fichier est trop lourd, envoyer une image warning
    if(filesize($image_completepath) > FILE_MAXSIZE){ return $image_default_oversize;}
    
    // okay, on doit fabriquer la vignette
    ini_set('memory_limit', '256M');
    list($width, $height, $type, $attr) = getimagesize($image_completepath);

    if($width < $destwidth or $height < $destheight){ 
        return $image_publicpath."?".filectime($image_completepath);
    }

    switch($ext){
        case 'gif': $img = imagecreatefromgif($image_completepath); break;
        case 'jpg': $img = imagecreatefromjpeg($image_completepath); break;
        case 'png': $img = imagecreatefrompng($image_completepath); break;
        case 'webp': $img = imagecreatefromwebp($image_completepath); break;
        default : echo "image does not exists"; return $image_default;
    }
    if($crop){
        $ratio = max($destwidth/$width, $destheight/$height);
        $y= ($height - $destheight / $ratio) /2;
        $x = ($width - $destwidth / $ratio) / 2;
        $height = $destheight / $ratio;
        $width = $destwidth / $ratio;
    } else {
        $ratio = min($destwidth/$width, $destheight/$height);
        $destwidth = $width * $ratio;
        $destheight = $height * $ratio;
        $x = 0;
        $y = 0;
    }

    $vignette = imagecreatetruecolor($destwidth, $destheight);

    // preserve transparency
    if($ext == "gif" or $ext == "png"){
        imagecolortransparent($vignette, imagecolorallocatealpha($vignette, 0, 0, 0, 127));
        imagealphablending($vignette, false);
        imagesavealpha($vignette, true);
    }

    imagecopyresampled($vignette, $img, 0, 0, $x, $y, $destwidth, $destheight, $width, $height);
    //$sharpen = array([-1,-1,-1], [-1, 16, -1], [-1,-1,-1]);
    //imageconvolution($vignette, $sharpen, 8, 0);

    switch($ext){
        case 'gif': imagegif($vignette, $vignette_completepath); break;
        case 'jpg': imagejpeg($vignette, $vignette_completepath); break;
        case 'png': imagepng($vignette, $vignette_completepath); break;
        case 'webp': imagewebp($vignette, $vignette_completepath); break;
    }
    imagedestroy($vignette);
    imagedestroy($img);

    return $vignette_publicpath."?".filectime($vignette_completepath);
}